CREATE TABLE foo (
    other     text NOT NULL,
    tagged    text NOT NULL,
    tag3      text NOT NULL,
    nulltext text
);

CREATE TABLE bar (
    other          text NOT NULL,
    also_tagged    text NOT NULL,
    tag3           text NOT NULL
);

CREATE TABLE baz (
    other          text NOT NULL,
    also_tagged    text NOT NULL,
    tag3           text NOT NULL
);
